pub fn parse_number_from_start<T>(input: &str, signed: bool) -> Result<T, T::Err>
where
    T: num_traits::PrimInt + std::str::FromStr,
    <T as std::str::FromStr>::Err: std::error::Error + Send + Sync + 'static,
{
    let end_number_idx = input
        .chars()
        .position(if signed {
            |c: char| !c.is_ascii_digit() && c != '-'
        } else {
            |c: char| !c.is_ascii_digit()
        })
        .unwrap_or(input.len());
    let res = input[..end_number_idx].parse::<T>()?;

    Ok(res)
}

pub fn parse_number_from_start_unsigned<T>(input: &str) -> Result<T, T::Err>
where
    T: num_traits::PrimInt + num_traits::Unsigned + std::str::FromStr,
    <T as std::str::FromStr>::Err: std::error::Error + Send + Sync + 'static,
{
    parse_number_from_start(input, false)
}

pub fn parse_number_from_start_signed<T>(input: &str) -> Result<T, T::Err>
where
    T: num_traits::PrimInt + num_traits::Signed + std::str::FromStr,
    <T as std::str::FromStr>::Err: std::error::Error + Send + Sync + 'static,
{
    parse_number_from_start(input, true)
}
